package VMOMI::HttpNfcLeaseState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
